=========================================
django-cabinet - Media library for Django
=========================================

.. image:: https://travis-ci.org/matthiask/django-cabinet.png?branch=master
   :target: https://travis-ci.org/matthiask/django-cabinet

django-cabinet is a media library for Django implemented while trying to
write as little code as possible to keep maintenance at a minimum.

- `Documentation <https://django-cabinet.readthedocs.io>`_
- `Github <https://github.com/matthiask/django-cabinet/>`_
